==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/FunnelSliceClickedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelSliceClickedEventArgsDescription } from "./FunnelSliceClickedEventArgsDescription";
/**
 * @hidden
 */
export let FunnelSliceClickedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FunnelSliceClickedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FunnelSliceClickedEventArgsDescriptionMetadata.a == null) {
                FunnelSliceClickedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FunnelSliceClickedEventArgsDescriptionMetadata.c(FunnelSliceClickedEventArgsDescriptionMetadata.a);
            }
            if (a.j(FunnelSliceClickedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(FunnelSliceClickedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Index", "Number:int");
            a.item("Bounds", "Rect");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            FunnelSliceClickedEventArgsDescriptionMetadata.b(a);
            a.aa("FunnelSliceClickedEventArgs", () => new FunnelSliceClickedEventArgsDescription());
            a.z("FunnelSliceClickedEventArgs", FunnelSliceClickedEventArgsDescriptionMetadata.a);
        }
    }
    FunnelSliceClickedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(FunnelSliceClickedEventArgsDescriptionMetadata, 'FunnelSliceClickedEventArgsDescriptionMetadata');
    FunnelSliceClickedEventArgsDescriptionMetadata.a = null;
    return FunnelSliceClickedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/FunnelSliceClickedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelSliceClickedEventArgsDescription } from "./FunnelSliceClickedEventArgsDescription";
/**
 * @hidden
 */
export let FunnelSliceClickedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FunnelSliceClickedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FunnelSliceClickedEventArgsDescriptionMetadata.a == null) {
                FunnelSliceClickedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FunnelSliceClickedEventArgsDescriptionMetadata.c(FunnelSliceClickedEventArgsDescriptionMetadata.a);
            }
            if (a.k(FunnelSliceClickedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(FunnelSliceClickedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Index", "Number:int");
            a.item("Bounds", "Rect");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            FunnelSliceClickedEventArgsDescriptionMetadata.b(a);
            a.ac("FunnelSliceClickedEventArgs", () => new FunnelSliceClickedEventArgsDescription());
            a.ab("FunnelSliceClickedEventArgs", FunnelSliceClickedEventArgsDescriptionMetadata.a);
        }
    }
    FunnelSliceClickedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(FunnelSliceClickedEventArgsDescriptionMetadata, 'FunnelSliceClickedEventArgsDescriptionMetadata');
    FunnelSliceClickedEventArgsDescriptionMetadata.a = null;
    return FunnelSliceClickedEventArgsDescriptionMetadata;
})();
